Calculate methane emissions from enteric fermentation
calculate_emissions_enteric.RdComputes enteric methane emissions based on Gross Energy (GE), Digestible Energy (DE), NDF, and Ym factor using IPCC Tier 2 logic.

calculate_emissions_enteric.RdComputes enteric methane emissions based on Gross Energy (GE), Digestible Energy (DE), NDF, and Ym factor using IPCC Tier 2 logic.