Calculate Cattle Population Structure
calculate_population_cattle.RdInternal helper to model the cattle herd based on mature population and biological rates.

calculate_population_cattle.RdInternal helper to model the cattle herd based on mature population and biological rates.